@@ -1,4 +1,5 @@
 library(nullabor)
+library(ggplot2)
 
 threept <- subset(lal, type == "3pt" & !is.na(x) & !is.na(y))
 threept <- threept[c(".id", "period", "time", "team", "etype", "player", "points", "result", "x", "y")]
@@ -18,9 +19,9 @@ qplot(x, y, data = threept) + coord_equal()
 angle_scale <- scale_x_continuous("Angle (degrees)", 
   breaks = c(0, 45, 90, 135, 180), limits = c(0, 180))
 
-qplot(angle * 180 / pi, r, data = threept) + 
-  angle_scale 
-  %+% lineup(null_lm(r ~ poly(angle, 2)), threept, n = 9)
+qplot(angle * 180 / pi, r, data = threept)  %+%
+  lineup(null_lm(r ~ poly(angle, 2)), threept, n = 9) +
+  angle_scale
 
 segment <- function(x, br) (x - br) * (x > br)
 qplot(angle * 180 / pi, r, data = threept) + angle_scale +
@@ -30,6 +31,6 @@ last_plot() %+% lineup(null_lm(r ~ angle + segment(angle, pi / 2)), n = 9)
 
 # Look at model residuals directly
 mod <- lm(r ~ poly(angle, 2), data = threept)
-inrange$resid <- resid(mod)
-qplot(angle, resid, data = inrange)
-last_plot() %+% lineup(has_dist("resid", "normal", list(mean = 0, sd = 1)))
\ No newline at end of file
+threept$resid <- resid(mod)
+qplot(angle, resid, data = threept)
+last_plot() %+% lineup(null_dist("resid", "normal", list(mean = 0, sd = 1)))
\ No newline at end of file
